#ifndef KXSEACHDIALOGIMPL_H
#define KXSEACHDIALOGIMPL_H
#include "kxsearchdialog.h"
#include <v2_codes.h>

class QListViewItem;

class kxSearchDialogImpl : public kxSearchDialog
{ 
    Q_OBJECT

public:
    kxSearchDialogImpl( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~kxSearchDialogImpl();

    
    bool search;
    int searchSeq;
    int count;
    

public slots:
  void SlotClicked(QListViewItem *);

	void SlotSearchFound(Q_UINT16, UIN, QString,QString,QString,QString, Q_UINT8,Q_UINT8, bool);
	void SlotSearchFailed(Q_UINT16);

  void SlotSearchButton();
  void SlotCancelButton();
  void SlotAddButton();
  void SlotInfoButton();
};


#endif // KXSEACHDIALOGIMPL_H
